==> kdelibs-2.2.tar.bz2: kdelibs-2.2/kdeprint/rlpr/kmrlprfactory.cpp <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 **/

#include "kmrlprfactory.h"
#include "kmrlprmanager.h"
#include "kmrlpruimanager.h"
#include "krlprprinterimpl.h"

extern "C"
{
	void* init_libkdeprint_rlpr()
	{
		return new KRlprFactory;
	}
};

KRlprFactory::KRlprFactory(QObject *parent, const char *name)
: KLibFactory(parent,name)
{
}

KRlprFactory::~KRlprFactory()
{
}

QObject* KRlprFactory::createObject(QObject *parent, const char *name, const char *classname, const QStringList&)
{
	if (strcmp(classname,"KMManager") == 0)
		return new KMRlprManager(parent,name);
	else if (strcmp(classname,"KMUiManager") == 0)
		return new KMRlprUiManager(parent,name);
	else if (strcmp(classname,"KPrinterImpl") == 0)
		return new KRlprPrinterImpl(parent,name);
	else
		return NULL;
}

==> kdelibs-3.0.3a.tar.bz2: kdelibs-3.0.3a/kdeprint/rlpr/kmrlprfactory.cpp <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 **/

#include "kmrlprfactory.h"
#include "kmrlprmanager.h"
#include "kmrlpruimanager.h"
#include "krlprprinterimpl.h"

extern "C"
{
	void* init_kdeprint_rlpr()
	{
		return new KRlprFactory;
	}
};

KRlprFactory::KRlprFactory(QObject *parent, const char *name)
: KLibFactory(parent,name)
{
}

KRlprFactory::~KRlprFactory()
{
}

QObject* KRlprFactory::createObject(QObject *parent, const char *name, const char *classname, const QStringList&)
{
	if (strcmp(classname,"KMManager") == 0)
		return new KMRlprManager(parent,name);
	else if (strcmp(classname,"KMUiManager") == 0)
		return new KMRlprUiManager(parent,name);
	else if (strcmp(classname,"KPrinterImpl") == 0)
		return new KRlprPrinterImpl(parent,name);
	else
		return NULL;
}
